Documentation
¶
Overview ¶
Package age implements file encryption according to age-encryption.org/v1.
This is a narrow copy of internal/age to allow encryption/decryption as a library.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrIncorrectIdentity = age.ErrIncorrectIdentity
Functions ¶
func EncryptWithArmor ¶
Types ¶
type Identity ¶
func GenerateX25519Identity ¶
func NewSSHRSAIdentity ¶
func NewSSHRSAIdentity(key *rsa.PrivateKey) (Identity, error)
func NewScryptIdentity ¶
func NewX25519Identity ¶
func ParseX25519Identity ¶
Directories
¶
| Path | Synopsis |
|---|---|
|
cmd
|
|
|
age
command
|
|
|
age-keygen
command
|
|
|
internal
|
|
|
age
Package age implements file encryption according to age-encryption.org/v1.
|
Package age implements file encryption according to age-encryption.org/v1. |
|
bech32
Package bech32 is a modified version of the reference implementation of BIP173.
|
Package bech32 is a modified version of the reference implementation of BIP173. |
|
format
Package format implements the age file format.
|
Package format implements the age file format. |
|
stream
Package stream implements a variant of the STREAM chunked encryption scheme.
|
Package stream implements a variant of the STREAM chunked encryption scheme. |
Click to show internal directories.
Click to hide internal directories.